# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
from .x_office_installation_directories import XOfficeInstallationDirectories as XOfficeInstallationDirectories_c38f12d9

class OfficeInstallationDirectories(XOfficeInstallationDirectories_c38f12d9):
    """
    Service Class

    encapsulates access to the current office installation directory and office user data directory, provides functionality to create URLs containing relocatable (not absolute) references to the current office installation directory and user data directory and vice versa.
    
    This functionality is useful when data containing references to the current office installation directory or user data directory must be made persistent and re-read later. In many cases, storing the reference directly would destroy the relocatability of an office installation and the possibility to share one office user data directory among parallel office installations.
    
    **since**
    
        OOo 2.0
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API OfficeInstallationDirectories <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1util_1_1OfficeInstallationDirectories.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.OfficeInstallationDirectories'
    __ooo_type_name__: str = 'service'


__all__ = ['OfficeInstallationDirectories']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.reflection
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_singleton_type_description import XSingletonTypeDescription as XSingletonTypeDescription_db781364
if typing.TYPE_CHECKING:
    from .x_type_description import XTypeDescription as XTypeDescription_3c210fb1

class XSingletonTypeDescription2(XSingletonTypeDescription_db781364):
    """
    Reflects a singleton, supporting interface-based singletons.
    
    This type supersedes XSingletonTypeDescription, which only supports obsolete, service-based singletons.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XSingletonTypeDescription2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XSingletonTypeDescription2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XSingletonTypeDescription2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XSingletonTypeDescription2'

    @abstractmethod
    def getInterface(self) -> XTypeDescription_3c210fb1:
        """
        Returns the interface type associated with the singleton.
        """
        ...
    @abstractmethod
    def isInterfaceBased(self) -> bool:
        """
        Returns whether this object reflects an interface-based singleton.
        """
        ...

__all__ = ['XSingletonTypeDescription2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..util.color import Color as Color_68e908c5

class ShadowProperties(ABC):
    """
    Service Class

    This is a set of properties to describe the style for rendering a shadow.

    See Also:
        `API ShadowProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1ShadowProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.ShadowProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Shadow(self) -> bool:
        """
        enables/disables the shadow of a Shape.
        
        The other shadow properties are only applied if this is set to TRUE.
        """
        ...

    @abstractproperty
    def ShadowBlur(self) -> int:
        """
        This defines the degree of blur of the shadow in points.
        """
        ...

    @abstractproperty
    def ShadowColor(self) -> Color_68e908c5:
        """
        This is the color of the shadow of this Shape.
        """
        ...

    @abstractproperty
    def ShadowTransparence(self) -> int:
        """
        This defines the degree of transparence of the shadow in percent.
        """
        ...

    @abstractproperty
    def ShadowXDistance(self) -> int:
        """
        This is the horizontal distance of the left edge of the Shape to the shadow.
        """
        ...

    @abstractproperty
    def ShadowYDistance(self) -> int:
        """
        This is the vertical distance of the top edge of the Shape to the shadow.
        """
        ...


__all__ = ['ShadowProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class CurveStyle(metaclass=UnoEnumMeta, type_name="com.sun.star.chart2.CurveStyle", name_space="com.sun.star.chart2"):
        """Dynamically created class that represents ``com.sun.star.chart2.CurveStyle`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.chart2.CurveStyle import B_SPLINES as CURVE_STYLE_B_SPLINES
        from com.sun.star.chart2.CurveStyle import CUBIC_SPLINES as CURVE_STYLE_CUBIC_SPLINES
        from com.sun.star.chart2.CurveStyle import LINES as CURVE_STYLE_LINES
        from com.sun.star.chart2.CurveStyle import NURBS as CURVE_STYLE_NURBS
        from com.sun.star.chart2.CurveStyle import STEP_CENTER_X as CURVE_STYLE_STEP_CENTER_X
        from com.sun.star.chart2.CurveStyle import STEP_CENTER_Y as CURVE_STYLE_STEP_CENTER_Y
        from com.sun.star.chart2.CurveStyle import STEP_END as CURVE_STYLE_STEP_END
        from com.sun.star.chart2.CurveStyle import STEP_START as CURVE_STYLE_STEP_START

        class CurveStyle(uno.Enum):
            """
            Enum Class


            See Also:
                `API CurveStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart2.html#a6eee32347565343ce84b84adb82da419>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.chart2.CurveStyle', value)

            __ooo_ns__: str = 'com.sun.star.chart2'
            __ooo_full_ns__: str = 'com.sun.star.chart2.CurveStyle'
            __ooo_type_name__: str = 'enum'

            B_SPLINES = CURVE_STYLE_B_SPLINES
            """
            Data points are connected via a parametric, interpolating B-spline curve.
            """
            CUBIC_SPLINES = CURVE_STYLE_CUBIC_SPLINES
            """
            Data points are connected via a smoothed cubic spline curve.

            The data points themselves are part of to the curve.
            """
            LINES = CURVE_STYLE_LINES
            """
            Lines between data points are not smoothed.
            """
            NURBS = CURVE_STYLE_NURBS
            """
            Non-uniform rational b-splines.
            """
            STEP_CENTER_X = CURVE_STYLE_STEP_CENTER_X
            """
            Data points are connected via a 3-segmented stepped line.

            The lines is horizontal till the center of the X values.
            """
            STEP_CENTER_Y = CURVE_STYLE_STEP_CENTER_Y
            """
            Data points are connected via a 3-segmented stepped line.

            The lines is horizontal at the center of the Y values.
            """
            STEP_END = CURVE_STYLE_STEP_END
            """
            Data points are connected via a 2-segmented stepped line.

            The line ends horizontally.
            """
            STEP_START = CURVE_STYLE_STEP_START
            """
            Data points are connected via a 2-segmented stepped line.

            The line starts horizontally.
            """
    else:
        # keep document generators happy
        from ...lo.chart2.curve_style import CurveStyle as CurveStyle


__all__ = ['CurveStyle']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.util.SearchAlgorithms import SearchAlgorithmsProto

class SearchAlgorithms(Enum):
    """
    Enum Class

    ENUM SearchAlgorithms

    See Also:
        `API SearchAlgorithms <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1util.html#a88c44d0f9aaded4e5618f3f8adcde79f>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.SearchAlgorithms'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.util.SearchAlgorithms'

    ABSOLUTE = cast("SearchAlgorithmsProto", 'ABSOLUTE')
    """
    Literal.
    """
    APPROXIMATE = cast("SearchAlgorithmsProto", 'APPROXIMATE')
    """
    Weighted Levenshtein Distance.
    """
    REGEXP = cast("SearchAlgorithmsProto", 'REGEXP')
    """
    Regular expression.
    """

__all__ = ['SearchAlgorithms']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_index_replace import XIndexReplace as XIndexReplace_feed0dd7

class NumberingRules(XPropertySet_bc180bfa, XIndexReplace_feed0dd7):
    """
    Service Class

    provides access to the numbering rules.
    
    Numbering rules may be set at a Paragraph object. The numbering rules are levels of property values. Each level contains equal properties.

    See Also:
        `API NumberingRules <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.NumberingRules'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DefaultListId(self) -> str:
        """
        id of default list for the numbering rules instance
        """
        ...

    @abstractproperty
    def IsAbsoluteMargins(self) -> bool:
        """
        determines if the margins are absolute or relative to the preceding numbering level.
        """
        ...

    @abstractproperty
    def IsAutomatic(self) -> bool:
        """
        determines if the numbering rules are automatically created as opposed to numbering rules that are part of a numbering style.
        """
        ...

    @abstractproperty
    def IsContinuousNumbering(self) -> bool:
        """
        determines if the numbering levels are counted continuously or if each numbering level is counted separately.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        contains the name of the numbering rules.
        
        It is used to identify a certain numbering rules property
        """
        ...

    @abstractproperty
    def NumberingIsOutline(self) -> bool:
        """
        This numbering is used in the outline of the document (e.g.
        
        headings).
        """
        ...

    @abstractproperty
    def NumberingType(self) -> int:
        """
        the type of numbering (Arabic, characters, roman numbers, etc.).
        """
        ...


__all__ = ['NumberingRules']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
from ..accessibility.x_accessible import XAccessible as XAccessible_1cbc0eb6
from ..accessibility.x_accessible_component import XAccessibleComponent as XAccessibleComponent_b2f21269
from ..accessibility.x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b

class AccessibleChartDocumentView(XAccessible_1cbc0eb6, XAccessibleComponent_b2f21269, XAccessibleContext_8eae119b):
    """
    Service Class

    The AccessibleChartDocumentView service is supported by a Component that represents the view of a Chart document to provide an entry point to the document tree for accessibility.
    
    An object that implements the AccessibleChartDocumentView service provides information about itself and about the chart subcomponents contained in the chart document displayed in a window. This service gives a simplified view on the underlying implementation. It tries both to keep the structure of the accessibility representation tree as simple as possible and provide as much relevant information as possible.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleChartDocumentView <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1AccessibleChartDocumentView.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.AccessibleChartDocumentView'
    __ooo_type_name__: str = 'service'


__all__ = ['AccessibleChartDocumentView']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class LineCap(metaclass=UnoEnumMeta, type_name="com.sun.star.drawing.LineCap", name_space="com.sun.star.drawing"):
        """Dynamically created class that represents ``com.sun.star.drawing.LineCap`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.drawing.LineCap import BUTT as LINE_CAP_BUTT
        from com.sun.star.drawing.LineCap import ROUND as LINE_CAP_ROUND
        from com.sun.star.drawing.LineCap import SQUARE as LINE_CAP_SQUARE

        class LineCap(uno.Enum):
            """
            Enum Class


            See Also:
                `API LineCap <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a6d67f779dcbc9e19f8bc6cdfbb6c23f8>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.drawing.LineCap', value)

            __ooo_ns__: str = 'com.sun.star.drawing'
            __ooo_full_ns__: str = 'com.sun.star.drawing.LineCap'
            __ooo_type_name__: str = 'enum'

            BUTT = LINE_CAP_BUTT
            """
            the line will end without any additional shape
            """
            ROUND = LINE_CAP_ROUND
            """
            the dash is a point

            the lines join with an arc

            the line will get a half circle as additional cap
            """
            SQUARE = LINE_CAP_SQUARE
            """
            the line will get a half square as additional cap

            the line uses a square for the line end.
            """
    else:
        # keep document generators happy
        from ...lo.drawing.line_cap import LineCap as LineCap


__all__ = ['LineCap']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from .x_text_range import XTextRange as XTextRange_9a910ab7

class XParagraphAppend(XInterface_8f010a43):
    """
    allows inserting and appending paragraphs.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API XParagraphAppend <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XParagraphAppend.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XParagraphAppend'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XParagraphAppend'

    @abstractmethod
    def finishParagraph(self, CharacterAndParagraphProperties: PropertyValues_d6470ce6) -> XTextRange_9a910ab7:
        """
        appends a new and empty paragraph at the end of the text.
        
        The properties are applied to the last paragraph before the new paragraph is inserted.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...
    @abstractmethod
    def finishParagraphInsert(self, CharacterAndParagraphProperties: PropertyValues_d6470ce6, TextRange: XTextRange_9a910ab7) -> XTextRange_9a910ab7:
        """
        inserts a new and empty paragraph to the text at a given position.
        
        The properties are applied to the last paragraph before the new paragraph is inserted.
        
        **since**
        
            LibreOffice 4.0

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...

__all__ = ['XParagraphAppend']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
from abc import abstractproperty
from .result_set import ResultSet as ResultSet_8ecf0a4f
from .x_parameters import XParameters as XParameters_a36c0b10
from .x_row_set import XRowSet as XRowSet_7a090960
if typing.TYPE_CHECKING:
    from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6

class RowSet(ResultSet_8ecf0a4f, XParameters_a36c0b10, XRowSet_7a090960):
    """
    Service Class

    is a client side ResultSet, which combines the characteristics of a com.sun.star.sdbc.Statement and a com.sun.star.sdbc.ResultSet.
    
    It acts like a typical bean. Before you use the RowSet, you have to specify a set of properties like a DataSource and a Command and other properties known of Statement. Afterwards, you can populate the RowSet by its execute method to fill the set with data.
    
    On the one hand, a RowSet can be used as a short cut to retrieve the data of a DataSource. You don't have to establish a connection, create a Statement, and then create a ResultSet. On the other hand, a row set can be used to implement capabilities for a result set, which are not supported by a driver result set, like caching strategies or update capabilities.

    See Also:
        `API RowSet <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.RowSet'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Command(self) -> str:
        """
        is the command which should be executed.
        """
        ...

    @abstractproperty
    def DataSourceName(self) -> str:
        """
        is the name of a named datasource to use.
        """
        ...

    @abstractproperty
    def EscapeProcessing(self) -> bool:
        """
        returns if escape processing is on or off.
        
        If escape scanning is on (the default), the driver will do escape substitution before sending the SQL to the database. This is only evaluated, if the CommandType is COMMAND.
        """
        ...

    @abstractproperty
    def MaxFieldSize(self) -> int:
        """
        returns the maximum number of bytes allowed for any column value.
        
        This limit is the maximum number of bytes that can be returned for any column value. The limit applies only to com.sun.star.sdbc.DataType.BINARY , com.sun.star.sdbc.DataType.VARBINARY , com.sun.star.sdbc.DataType.LONGVARBINARY , com.sun.star.sdbc.DataType.CHAR , com.sun.star.sdbc.DataType.VARCHAR , and com.sun.star.sdbc.DataType.LONGVARCHAR columns. If the limit is exceeded, the excess data is silently discarded. There is no limitation, if set to zero.
        """
        ...

    @abstractproperty
    def MaxRows(self) -> int:
        """
        retrieves the maximum number of rows that a ResultSet can contain.
        
        If the limit is exceeded, the excess rows are silently dropped. There is no limitation, if set to zero.
        """
        ...

    @abstractproperty
    def Password(self) -> str:
        """
        determines the user for whom to open the connection.
        """
        ...

    @abstractproperty
    def QueryTimeOut(self) -> int:
        """
        retrieves the number of seconds the driver will wait for a Statement to execute.
        
        If the limit is exceeded, a com.sun.star.sdbc.SQLException is thrown. There is no limitation, if set to zero.
        """
        ...

    @abstractproperty
    def ResultSetType(self) -> int:
        """
        determine the result set type.
        """
        ...

    @abstractproperty
    def TransactionIsolation(self) -> int:
        """
        indicates the transaction isolation level, which should be used for the connection.
        """
        ...

    @abstractproperty
    def TypeMap(self) -> XNameAccess_e2ab0cf6:
        """
        is the type map that will be used for the custom mapping of SQL structured types and distinct types.
        """
        ...

    @abstractproperty
    def URL(self) -> str:
        """
        is the connection URL.
        
        Could be used instead of the DataSourceName.
        """
        ...

    @abstractproperty
    def User(self) -> str:
        """
        determines the user for whom to open the connection.
        """
        ...


__all__ = ['RowSet']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..chart.time_increment import TimeIncrement as TimeIncrement_c7e70c4e
from .axis_orientation import AxisOrientation as AxisOrientation_ecba0d6d
from .increment_data import IncrementData as IncrementData_d2000c6b
from .x_scaling import XScaling as XScaling_97500a65
from .data.x_labeled_data_sequence import XLabeledDataSequence as XLabeledDataSequence_7e1a10c8


class ScaleData(object):
    """
    Struct Class


    See Also:
        `API ScaleData <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1ScaleData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.ScaleData'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.chart2.ScaleData'
    """Literal Constant ``com.sun.star.chart2.ScaleData``"""

    def __init__(self, Minimum: typing.Optional[object] = None, Maximum: typing.Optional[object] = None, Origin: typing.Optional[object] = None, Orientation: typing.Optional[AxisOrientation_ecba0d6d] = AxisOrientation_ecba0d6d.MATHEMATICAL, Scaling: typing.Optional[XScaling_97500a65] = None, Categories: typing.Optional[XLabeledDataSequence_7e1a10c8] = None, AxisType: typing.Optional[int] = 0, AutoDateAxis: typing.Optional[bool] = False, ShiftedCategoryPosition: typing.Optional[bool] = False, IncrementData: typing.Optional[IncrementData_d2000c6b] = UNO_NONE, TimeIncrement: typing.Optional[TimeIncrement_c7e70c4e] = UNO_NONE) -> None:
        """
        Constructor

        Arguments:
            Minimum (object, optional): Minimum value.
            Maximum (object, optional): Maximum value.
            Origin (object, optional): Origin value.
            Orientation (AxisOrientation, optional): Orientation value.
            Scaling (XScaling, optional): Scaling value.
            Categories (XLabeledDataSequence, optional): Categories value.
            AxisType (int, optional): AxisType value.
            AutoDateAxis (bool, optional): AutoDateAxis value.
            ShiftedCategoryPosition (bool, optional): ShiftedCategoryPosition value.
            IncrementData (IncrementData, optional): IncrementData value.
            TimeIncrement (TimeIncrement, optional): TimeIncrement value.
        """
        super().__init__()

        if isinstance(Minimum, ScaleData):
            oth: ScaleData = Minimum
            self.Minimum = oth.Minimum
            self.Maximum = oth.Maximum
            self.Origin = oth.Origin
            self.Orientation = oth.Orientation
            self.Scaling = oth.Scaling
            self.Categories = oth.Categories
            self.AxisType = oth.AxisType
            self.AutoDateAxis = oth.AutoDateAxis
            self.ShiftedCategoryPosition = oth.ShiftedCategoryPosition
            self.IncrementData = oth.IncrementData
            self.TimeIncrement = oth.TimeIncrement
            return

        kargs = {
            "Minimum": Minimum,
            "Maximum": Maximum,
            "Origin": Origin,
            "Orientation": Orientation,
            "Scaling": Scaling,
            "Categories": Categories,
            "AxisType": AxisType,
            "AutoDateAxis": AutoDateAxis,
            "ShiftedCategoryPosition": ShiftedCategoryPosition,
            "IncrementData": IncrementData,
            "TimeIncrement": TimeIncrement,
        }
        if kargs["IncrementData"] is UNO_NONE:
            kargs["IncrementData"] = None
        if kargs["TimeIncrement"] is UNO_NONE:
            kargs["TimeIncrement"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._minimum = kwargs["Minimum"]
        self._maximum = kwargs["Maximum"]
        self._origin = kwargs["Origin"]
        self._orientation = kwargs["Orientation"]
        self._scaling = kwargs["Scaling"]
        self._categories = kwargs["Categories"]
        self._axis_type = kwargs["AxisType"]
        self._auto_date_axis = kwargs["AutoDateAxis"]
        self._shifted_category_position = kwargs["ShiftedCategoryPosition"]
        self._increment_data = kwargs["IncrementData"]
        self._time_increment = kwargs["TimeIncrement"]


    @property
    def Minimum(self) -> object:
        """
        if the any contains a double value this is used as a fixed maximum.
        
        Otherwise, if the any is empty or contains an incompatible type, the maximum is automatic.
        
        If the maximum is automatic, this means, each view that represents the model containing this scale, has to calculate a maximum by its own means.
        """
        return self._minimum

    @Minimum.setter
    def Minimum(self, value: object) -> None:
        self._minimum = value

    @property
    def Maximum(self) -> object:
        """
        if the any contains a double value this is used as a fixed minimum.
        
        Otherwise, if the any is empty or contains an incompatible type, the minimum is automatic.
        
        If the minimum is automatic, this means, each view that represents the model containing this scale, has to calculate a minimum by its own means.
        """
        return self._maximum

    @Maximum.setter
    def Maximum(self, value: object) -> None:
        self._maximum = value

    @property
    def Origin(self) -> object:
        """
        The Origin indicates where other axes cross this axis.
        
        If the any contains a double value that value is used. Otherwise an appropriate value has to be calculated by that instances using Origin.
        """
        return self._origin

    @Origin.setter
    def Origin(self, value: object) -> None:
        self._origin = value

    @property
    def Orientation(self) -> AxisOrientation_ecba0d6d:
        """
        Axis orientation (standard or reversed).
        
        If used at the Y axis in pie charts or doughnut charts, specifies the rotation direction of the pie. The value AxisOrientation.MATHEMATICAL rotates the pie counterclockwise, the value AxisOrientation.REVERSE rotates the pie clockwise.
        
        Note: Is this a good place for the axis orientation? Two axes may use the same scale, but point into two different directions.
        """
        return self._orientation

    @Orientation.setter
    def Orientation(self, value: AxisOrientation_ecba0d6d) -> None:
        self._orientation = value

    @property
    def Scaling(self) -> XScaling_97500a65:
        return self._scaling

    @Scaling.setter
    def Scaling(self, value: XScaling_97500a65) -> None:
        self._scaling = value

    @property
    def Categories(self) -> XLabeledDataSequence_7e1a10c8:
        return self._categories

    @Categories.setter
    def Categories(self, value: XLabeledDataSequence_7e1a10c8) -> None:
        self._categories = value

    @property
    def AxisType(self) -> int:
        """
        describes the type of the axis.
        
        It can be a real number axis or a category axis or something else. AxisType is one value out of the constant group AxisType.
        """
        return self._axis_type

    @AxisType.setter
    def AxisType(self, value: int) -> None:
        self._axis_type = value

    @property
    def AutoDateAxis(self) -> bool:
        """
        if true an AxisType CATEGORY is interpreted as DATE if the underlying data given in Categories are dates
        """
        return self._auto_date_axis

    @AutoDateAxis.setter
    def AutoDateAxis(self, value: bool) -> None:
        self._auto_date_axis = value

    @property
    def ShiftedCategoryPosition(self) -> bool:
        """
        describes whether data points on category or date axis are placed between tickmarks or not if true the maximum on the scale will be expanded for one interval
        """
        return self._shifted_category_position

    @ShiftedCategoryPosition.setter
    def ShiftedCategoryPosition(self, value: bool) -> None:
        self._shifted_category_position = value

    @property
    def IncrementData(self) -> IncrementData_d2000c6b:
        """
        increment data to be used for not date-time axis
        """
        return self._increment_data

    @IncrementData.setter
    def IncrementData(self, value: IncrementData_d2000c6b) -> None:
        self._increment_data = value

    @property
    def TimeIncrement(self) -> TimeIncrement_c7e70c4e:
        """
        increment data to be used in case of date-time axis
        """
        return self._time_increment

    @TimeIncrement.setter
    def TimeIncrement(self, value: TimeIncrement_c7e70c4e) -> None:
        self._time_increment = value


__all__ = ['ScaleData']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from .table_column_separator import TableColumnSeparator as TableColumnSeparator_1b630ed4
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.style.GraphicLocation import GraphicLocationProto

class TextTableRow(XPropertySet_bc180bfa):
    """
    Service Class

    specifies the properties of a text table row.
    
    **since**
    
        LibreOffice 4.4

    See Also:
        `API TextTableRow <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.TextTableRow'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def RowInteropGrabBag(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        Grab bag of row properties, used as a string-any map for interop purposes.
        
        This property is intentionally not handled by the ODF filter. Any member that should be handled there should be first moved out from this grab bag to a separate property.
        
        **since**
        
            LibreOffice 4.4
        """
        ...

    @abstractproperty
    def TableColumnSeparators(self) -> typing.Tuple[TableColumnSeparator_1b630ed4, ...]:
        """
        contains the description of the columns in the table row.
        """
        ...

    @abstractproperty
    def BackColor(self) -> Color_68e908c5:
        """
        specifies the color of the background.
        """
        ...

    @abstractproperty
    def BackGraphic(self) -> XGraphic_a4da0afc:
        """
        contains the graphic of the background.
        
        **since**
        
            LibreOffice 6.1
        """
        ...

    @abstractproperty
    def BackGraphicFilter(self) -> str:
        """
        contains the name of the file filter of a background graphic.
        """
        ...

    @abstractproperty
    def BackGraphicLocation(self) -> GraphicLocationProto:
        """
        determines the position of the background graphic.
        """
        ...

    @abstractproperty
    def BackGraphicURL(self) -> str:
        """
        contains the URL of a background graphic.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the BackGraphic property.
        """
        ...

    @abstractproperty
    def BackTransparent(self) -> bool:
        """
        If TRUE, the background color value in \"BackColor\" is not visible.
        """
        ...

    @abstractproperty
    def HasTextChangesOnly(self) -> bool:
        """
        If TRUE, the table row wasn't deleted or inserted with its tracked cell content.
        
        **since**
        
            LibreOffice 7.2
        """
        ...

    @abstractproperty
    def Height(self) -> int:
        """
        contains the height of the table row.
        """
        ...

    @abstractproperty
    def IsAutoHeight(self) -> bool:
        """
        If the value of this property is TRUE, the height of the table row depends on the content of the table cells.
        """
        ...

    @abstractproperty
    def IsSplitAllowed(self) -> bool:
        """
        If TRUE, the row is allowed to be split at page or column breaks.
        """
        ...


__all__ = ['TextTableRow']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto.sax
from __future__ import annotations
import typing
from abc import abstractmethod
from .xsax_event_keeper import XSAXEventKeeper as XSAXEventKeeper_65aa1044
if typing.TYPE_CHECKING:
    from com.sun.star.xml.crypto.sax.ElementMarkPriority import ElementMarkPriorityProto

class XSecuritySAXEventKeeper(XSAXEventKeeper_65aa1044):
    """
    Interface of Security SAX Event Keeper.
    
    This interface is an extension of the XSAXEventKeeper interface, some security related features are added.

    See Also:
        `API XSecuritySAXEventKeeper <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XSecuritySAXEventKeeper.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto.sax'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.sax.XSecuritySAXEventKeeper'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.crypto.sax.XSecuritySAXEventKeeper'

    @abstractmethod
    def addSecurityElementCollector(self, priority: ElementMarkPriorityProto, modifyElement: bool) -> int:
        """
        Adds a new element collector on the next element in the SAX event stream.
        """
        ...
    @abstractmethod
    def setSecurityId(self, id: int, securityId: int) -> None:
        """
        Sets security id for an element mark.
        """
        ...

__all__ = ['XSecuritySAXEventKeeper']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from abc import abstractproperty
from .base_index import BaseIndex as BaseIndex_8f0d0a40

class IllustrationsIndex(BaseIndex_8f0d0a40):
    """
    Service Class

    specifies service of illustration indexes within a document.

    See Also:
        `API IllustrationsIndex <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1IllustrationsIndex.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.IllustrationsIndex'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CreateFromLabels(self) -> bool:
        """
        """
        ...

    @abstractproperty
    def LabelCategory(self) -> str:
        """
        """
        ...

    @abstractproperty
    def LabelDisplayType(self) -> int:
        """
        """
        ...


__all__ = ['IllustrationsIndex']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.xpath
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class XPathObjectType(metaclass=UnoEnumMeta, type_name="com.sun.star.xml.xpath.XPathObjectType", name_space="com.sun.star.xml.xpath"):
        """Dynamically created class that represents ``com.sun.star.xml.xpath.XPathObjectType`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.xml.xpath.XPathObjectType import XPATH_BOOLEAN as X_PATH_OBJECT_TYPE_XPATH_BOOLEAN
        from com.sun.star.xml.xpath.XPathObjectType import XPATH_LOCATIONSET as X_PATH_OBJECT_TYPE_XPATH_LOCATIONSET
        from com.sun.star.xml.xpath.XPathObjectType import XPATH_NODESET as X_PATH_OBJECT_TYPE_XPATH_NODESET
        from com.sun.star.xml.xpath.XPathObjectType import XPATH_NUMBER as X_PATH_OBJECT_TYPE_XPATH_NUMBER
        from com.sun.star.xml.xpath.XPathObjectType import XPATH_POINT as X_PATH_OBJECT_TYPE_XPATH_POINT
        from com.sun.star.xml.xpath.XPathObjectType import XPATH_RANGE as X_PATH_OBJECT_TYPE_XPATH_RANGE
        from com.sun.star.xml.xpath.XPathObjectType import XPATH_STRING as X_PATH_OBJECT_TYPE_XPATH_STRING
        from com.sun.star.xml.xpath.XPathObjectType import XPATH_UNDEFINED as X_PATH_OBJECT_TYPE_XPATH_UNDEFINED
        from com.sun.star.xml.xpath.XPathObjectType import XPATH_USERS as X_PATH_OBJECT_TYPE_XPATH_USERS
        from com.sun.star.xml.xpath.XPathObjectType import XPATH_XSLT_TREE as X_PATH_OBJECT_TYPE_XPATH_XSLT_TREE

        class XPathObjectType(uno.Enum):
            """
            Enum Class

            ENUM XPathObjectType

            See Also:
                `API XPathObjectType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1xpath.html#a4e7de3ae7d09203486b85490e0a6f1a3>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.xml.xpath.XPathObjectType', value)

            __ooo_ns__: str = 'com.sun.star.xml.xpath'
            __ooo_full_ns__: str = 'com.sun.star.xml.xpath.XPathObjectType'
            __ooo_type_name__: str = 'enum'

            XPATH_BOOLEAN = X_PATH_OBJECT_TYPE_XPATH_BOOLEAN
            """
            """
            XPATH_LOCATIONSET = X_PATH_OBJECT_TYPE_XPATH_LOCATIONSET
            """
            """
            XPATH_NODESET = X_PATH_OBJECT_TYPE_XPATH_NODESET
            """
            """
            XPATH_NUMBER = X_PATH_OBJECT_TYPE_XPATH_NUMBER
            """
            """
            XPATH_POINT = X_PATH_OBJECT_TYPE_XPATH_POINT
            """
            """
            XPATH_RANGE = X_PATH_OBJECT_TYPE_XPATH_RANGE
            """
            """
            XPATH_STRING = X_PATH_OBJECT_TYPE_XPATH_STRING
            """
            """
            XPATH_UNDEFINED = X_PATH_OBJECT_TYPE_XPATH_UNDEFINED
            """
            """
            XPATH_USERS = X_PATH_OBJECT_TYPE_XPATH_USERS
            """
            """
            XPATH_XSLT_TREE = X_PATH_OBJECT_TYPE_XPATH_XSLT_TREE
            """
            """
    else:
        # keep document generators happy
        from ....lo.xml.xpath.x_path_object_type import XPathObjectType as XPathObjectType


__all__ = ['XPathObjectType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from ..accessibility.x_accessible_action import XAccessibleAction as XAccessibleAction_7ccc1114
from .accessible_shape import AccessibleShape as AccessibleShape_fdd20dd3

class AccessibleOLEShape(AccessibleShape_fdd20dd3, XAccessibleAction_7ccc1114):
    """
    Service Class

    The AccessibleOLEShape service is implemented by OLE shapes.
    
    This includes generic OLE shapes, frames, plug-ins, and applets.
    
    This service supports the additional com.sun.star.accessibility.XAccessibleAction interface.
    
    OLE objects are handled as place holders. While not activated the accessible OLE shape is the only indicator of the OLE object's existence. When an OLE object has been activated then the accessibility tree representing it (as far as that is available) is included directly under the accessible document view and not under the OLE object. This is due to underlying implementation constraints and may change in the future.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleOLEShape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleOLEShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.AccessibleOLEShape'
    __ooo_type_name__: str = 'service'


__all__ = ['AccessibleOLEShape']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet


class FormulaMapGroup(object):
    """
    Const Class

    Constants of bit masks used with XFormulaOpCodeMapper.getAvailableMappings() to specify for which group of symbols the mappings are to be obtained.
    
    If no bit is set, a sequence of special mappings is returned in the order that is defined by FormulaMapGroupSpecialOffset. Note that the special group and other groups are mutual exclusive.

    See Also:
        `API FormulaMapGroup <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroup.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.FormulaMapGroup'
    __ooo_type_name__: str = 'const'

    SPECIAL = 0
    """
    Group of op-codes without a string symbol.
    """
    SEPARATORS = 1
    """
    Separators and parentheses.
    """
    ARRAY_SEPARATORS = 2
    """
    Separators and parentheses for constant arrays.
    """
    UNARY_OPERATORS = 4
    """
    Unary operators.
    """
    BINARY_OPERATORS = 8
    """
    Binary operators.
    """
    FUNCTIONS = 16
    """
    Functions.
    """
    ALL_EXCEPT_SPECIAL = 2147483647
    """
    All groups except SPECIAL.
    """

__all__ = ['FormulaMapGroup']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class WebDAVHTTPMethod(metaclass=UnoEnumMeta, type_name="com.sun.star.ucb.WebDAVHTTPMethod", name_space="com.sun.star.ucb"):
        """Dynamically created class that represents ``com.sun.star.ucb.WebDAVHTTPMethod`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.ucb.WebDAVHTTPMethod import CONNECT as WEB_D_A_V_H_T_T_P_METHOD_CONNECT
        from com.sun.star.ucb.WebDAVHTTPMethod import COPY as WEB_D_A_V_H_T_T_P_METHOD_COPY
        from com.sun.star.ucb.WebDAVHTTPMethod import DELETE as WEB_D_A_V_H_T_T_P_METHOD_DELETE
        from com.sun.star.ucb.WebDAVHTTPMethod import GET as WEB_D_A_V_H_T_T_P_METHOD_GET
        from com.sun.star.ucb.WebDAVHTTPMethod import HEAD as WEB_D_A_V_H_T_T_P_METHOD_HEAD
        from com.sun.star.ucb.WebDAVHTTPMethod import LOCK as WEB_D_A_V_H_T_T_P_METHOD_LOCK
        from com.sun.star.ucb.WebDAVHTTPMethod import MKCOL as WEB_D_A_V_H_T_T_P_METHOD_MKCOL
        from com.sun.star.ucb.WebDAVHTTPMethod import MOVE as WEB_D_A_V_H_T_T_P_METHOD_MOVE
        from com.sun.star.ucb.WebDAVHTTPMethod import OPTIONS as WEB_D_A_V_H_T_T_P_METHOD_OPTIONS
        from com.sun.star.ucb.WebDAVHTTPMethod import PATCH as WEB_D_A_V_H_T_T_P_METHOD_PATCH
        from com.sun.star.ucb.WebDAVHTTPMethod import POST as WEB_D_A_V_H_T_T_P_METHOD_POST
        from com.sun.star.ucb.WebDAVHTTPMethod import PROPFIND as WEB_D_A_V_H_T_T_P_METHOD_PROPFIND
        from com.sun.star.ucb.WebDAVHTTPMethod import PROPPATCH as WEB_D_A_V_H_T_T_P_METHOD_PROPPATCH
        from com.sun.star.ucb.WebDAVHTTPMethod import PUT as WEB_D_A_V_H_T_T_P_METHOD_PUT
        from com.sun.star.ucb.WebDAVHTTPMethod import TRACE as WEB_D_A_V_H_T_T_P_METHOD_TRACE
        from com.sun.star.ucb.WebDAVHTTPMethod import UNLOCK as WEB_D_A_V_H_T_T_P_METHOD_UNLOCK

        class WebDAVHTTPMethod(uno.Enum):
            """
            Enum Class


            See Also:
                `API WebDAVHTTPMethod <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.ucb.WebDAVHTTPMethod', value)

            __ooo_ns__: str = 'com.sun.star.ucb'
            __ooo_full_ns__: str = 'com.sun.star.ucb.WebDAVHTTPMethod'
            __ooo_type_name__: str = 'enum'

            CONNECT = WEB_D_A_V_H_T_T_P_METHOD_CONNECT
            """
            HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
            """
            COPY = WEB_D_A_V_H_T_T_P_METHOD_COPY
            """
            Copy the source to the target folder.

            WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
            """
            DELETE = WEB_D_A_V_H_T_T_P_METHOD_DELETE
            """
            HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
            """
            GET = WEB_D_A_V_H_T_T_P_METHOD_GET
            """
            Get a list of all folders.

            HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
            """
            HEAD = WEB_D_A_V_H_T_T_P_METHOD_HEAD
            """
            HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
            """
            LOCK = WEB_D_A_V_H_T_T_P_METHOD_LOCK
            """
            WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
            """
            MKCOL = WEB_D_A_V_H_T_T_P_METHOD_MKCOL
            """
            WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
            """
            MOVE = WEB_D_A_V_H_T_T_P_METHOD_MOVE
            """
            Move the source to the target folder.

            WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
            """
            OPTIONS = WEB_D_A_V_H_T_T_P_METHOD_OPTIONS
            """
            HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
            """
            PATCH = WEB_D_A_V_H_T_T_P_METHOD_PATCH
            """
            HTTP request method as defined in RFC 5789: PATCH Method for HTTP
            """
            POST = WEB_D_A_V_H_T_T_P_METHOD_POST
            """
            HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
            """
            PROPFIND = WEB_D_A_V_H_T_T_P_METHOD_PROPFIND
            """
            WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
            """
            PROPPATCH = WEB_D_A_V_H_T_T_P_METHOD_PROPPATCH
            """
            WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
            """
            PUT = WEB_D_A_V_H_T_T_P_METHOD_PUT
            """
            HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
            """
            TRACE = WEB_D_A_V_H_T_T_P_METHOD_TRACE
            """
            HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
            """
            UNLOCK = WEB_D_A_V_H_T_T_P_METHOD_UNLOCK
            """
            WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
            """
    else:
        # keep document generators happy
        from ...lo.ucb.web_davhttp_method import WebDAVHTTPMethod as WebDAVHTTPMethod


__all__ = ['WebDAVHTTPMethod']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.ucb.PropertyValueState import PropertyValueStateProto

class PropertyValueState(Enum):
    """
    Enum Class


    See Also:
        `API PropertyValueState <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#a82ef3fdcd414866879e7aae1e52748d0>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.PropertyValueState'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.ucb.PropertyValueState'

    INVALID_NAME = cast("PropertyValueStateProto", 'INVALID_NAME')
    """
    The given property name/handle is invalid.
    """
    INVALID_TYPE = cast("PropertyValueStateProto", 'INVALID_TYPE')
    """
    The given property type is invalid.
    """
    PROCESSED = cast("PropertyValueStateProto", 'PROCESSED')
    """
    The value was obtained.
    """
    UNPROCESSED = cast("PropertyValueStateProto", 'UNPROCESSED')
    """
    The property value was not obtained yet.
    """

__all__ = ['PropertyValueState']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report.inspection
from __future__ import annotations
from abc import abstractmethod
from ...inspection.x_object_inspector_model import XObjectInspectorModel as XObjectInspectorModel_9077119b

class DefaultComponentInspectorModel(XObjectInspectorModel_9077119b):
    """
    Service Class

    implements a com.sun.star.inspection.XObjectInspectorModel for inspecting form components, in particular all components implementing the ReportComponent service.
    
    A DefaultComponentInspectorModel provides the following handlers by default:
    
    **since**
    
        OOo 2.2

    See Also:
        `API DefaultComponentInspectorModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1report_1_1inspection_1_1DefaultComponentInspectorModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report.inspection'
    __ooo_full_ns__: str = 'com.sun.star.report.inspection.DefaultComponentInspectorModel'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createDefault(self) -> None:
        """
        creates a default DefaultComponentInspectorModel, providing factories for all handlers listed above.
        
        **since**
        
            OOo 2.2
        """
        ...
    @abstractmethod
    def createWithHelpSection(self, minHelpTextLines: int, maxHelpTextLines: int) -> None:
        """
        creates a default DefaultComponentInspectorModel, providing factories for all handlers listed above, and describing an ObjectInspector which has a help section.
        
        **since**
        
            OOo 2.2

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['DefaultComponentInspectorModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
from ..lang.x_single_service_factory import XSingleServiceFactory as XSingleServiceFactory_27210f0d
from ..util.x_refreshable import XRefreshable as XRefreshable_b0d60b81

class DefinitionContainer(XEnumerationAccess_4bac0ffc, XIndexAccess_f0910d6d, XNameContainer_cb90e47, XSingleServiceFactory_27210f0d, XRefreshable_b0d60b81):
    """
    Service Class

    describes a container which provides access to database related definitions like commands, forms, and reports.
    
    The container supports access to its elements by the elements name or by the elements position.
    
    Simple enumeration must be supported as well.
    
    To reflect the changes with the underlying database, a refresh mechanism needs to be supported.

    See Also:
        `API DefinitionContainer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DefinitionContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DefinitionContainer'
    __ooo_type_name__: str = 'service'


__all__ = ['DefinitionContainer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
from .x_active_data_source import XActiveDataSource as XActiveDataSource_d1900c7f
from .x_connectable import XConnectable as XConnectable_980a0a96
from .x_markable_stream import XMarkableStream as XMarkableStream_b9bc0bc3
from .x_output_stream import XOutputStream as XOutputStream_a4e00b35

class MarkableOutputStream(XActiveDataSource_d1900c7f, XConnectable_980a0a96, XMarkableStream_b9bc0bc3, XOutputStream_a4e00b35):
    """
    Service Class

    allows to set marks in an outputstream and to later jump back to these marks.
    
    The implementation stores the data as long as marks exists and later writes these data into the output stream, that has been set previously at the XActiveDataSource interface.

    See Also:
        `API MarkableOutputStream <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1io_1_1MarkableOutputStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.MarkableOutputStream'
    __ooo_type_name__: str = 'service'


__all__ = ['MarkableOutputStream']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.embed
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..beans.named_value import NamedValue as NamedValue_a37a0af3
from .x_embedded_object import XEmbeddedObject as XEmbeddedObject_ddee0cbe


class InsertedObjectInfo(object):
    """
    Struct Class

    is intended to provide result of creation of an embedded object by dialog.

    See Also:
        `API InsertedObjectInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1embed_1_1InsertedObjectInfo.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.InsertedObjectInfo'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.embed.InsertedObjectInfo'
    """Literal Constant ``com.sun.star.embed.InsertedObjectInfo``"""

    def __init__(self, Options: typing.Optional[typing.Tuple[NamedValue_a37a0af3, ...]] = (), Object: typing.Optional[XEmbeddedObject_ddee0cbe] = None) -> None:
        """
        Constructor

        Arguments:
            Options (typing.Tuple[NamedValue, ...], optional): Options value.
            Object (XEmbeddedObject, optional): Object value.
        """
        super().__init__()

        if isinstance(Options, InsertedObjectInfo):
            oth: InsertedObjectInfo = Options
            self.Options = oth.Options
            self.Object = oth.Object
            return

        kargs = {
            "Options": Options,
            "Object": Object,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._options = kwargs["Options"]
        self._object = kwargs["Object"]


    @property
    def Options(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        Container related options selected by user.
        
        A dialog related to embedded object creation usually allows user to make some choices that can be container related. This information can be provided by this member.
        """
        return self._options

    @Options.setter
    def Options(self, value: typing.Tuple[NamedValue_a37a0af3, ...]) -> None:
        self._options = value

    @property
    def Object(self) -> XEmbeddedObject_ddee0cbe:
        """
        The new created embedded object.
        """
        return self._object

    @Object.setter
    def Object(self, value: XEmbeddedObject_ddee0cbe) -> None:
        self._object = value


__all__ = ['InsertedObjectInfo']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Panose(object):
    """
    Struct Class


    See Also:
        `API Panose <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1Panose.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.Panose'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.rendering.Panose'
    """Literal Constant ``com.sun.star.rendering.Panose``"""

    def __init__(self, FamilyType: typing.Optional[int] = 0, SerifStyle: typing.Optional[int] = 0, Weight: typing.Optional[int] = 0, Proportion: typing.Optional[int] = 0, Contrast: typing.Optional[int] = 0, StrokeVariation: typing.Optional[int] = 0, ArmStyle: typing.Optional[int] = 0, Letterform: typing.Optional[int] = 0, Midline: typing.Optional[int] = 0, XHeight: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            FamilyType (int, optional): FamilyType value.
            SerifStyle (int, optional): SerifStyle value.
            Weight (int, optional): Weight value.
            Proportion (int, optional): Proportion value.
            Contrast (int, optional): Contrast value.
            StrokeVariation (int, optional): StrokeVariation value.
            ArmStyle (int, optional): ArmStyle value.
            Letterform (int, optional): Letterform value.
            Midline (int, optional): Midline value.
            XHeight (int, optional): XHeight value.
        """
        super().__init__()

        if isinstance(FamilyType, Panose):
            oth: Panose = FamilyType
            self.FamilyType = oth.FamilyType
            self.SerifStyle = oth.SerifStyle
            self.Weight = oth.Weight
            self.Proportion = oth.Proportion
            self.Contrast = oth.Contrast
            self.StrokeVariation = oth.StrokeVariation
            self.ArmStyle = oth.ArmStyle
            self.Letterform = oth.Letterform
            self.Midline = oth.Midline
            self.XHeight = oth.XHeight
            return

        kargs = {
            "FamilyType": FamilyType,
            "SerifStyle": SerifStyle,
            "Weight": Weight,
            "Proportion": Proportion,
            "Contrast": Contrast,
            "StrokeVariation": StrokeVariation,
            "ArmStyle": ArmStyle,
            "Letterform": Letterform,
            "Midline": Midline,
            "XHeight": XHeight,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._family_type = kwargs["FamilyType"]
        self._serif_style = kwargs["SerifStyle"]
        self._weight = kwargs["Weight"]
        self._proportion = kwargs["Proportion"]
        self._contrast = kwargs["Contrast"]
        self._stroke_variation = kwargs["StrokeVariation"]
        self._arm_style = kwargs["ArmStyle"]
        self._letterform = kwargs["Letterform"]
        self._midline = kwargs["Midline"]
        self._x_height = kwargs["XHeight"]


    @property
    def FamilyType(self) -> int:
        """
        PanoseFamilyTypes.
        """
        return self._family_type

    @FamilyType.setter
    def FamilyType(self, value: int) -> None:
        self._family_type = value

    @property
    def SerifStyle(self) -> int:
        """
        PanoseSerifStyle.
        """
        return self._serif_style

    @SerifStyle.setter
    def SerifStyle(self, value: int) -> None:
        self._serif_style = value

    @property
    def Weight(self) -> int:
        """
        PanoseWeight.
        """
        return self._weight

    @Weight.setter
    def Weight(self, value: int) -> None:
        self._weight = value

    @property
    def Proportion(self) -> int:
        """
        PanoseProportion.
        """
        return self._proportion

    @Proportion.setter
    def Proportion(self, value: int) -> None:
        self._proportion = value

    @property
    def Contrast(self) -> int:
        """
        PanoseContrast.
        """
        return self._contrast

    @Contrast.setter
    def Contrast(self, value: int) -> None:
        self._contrast = value

    @property
    def StrokeVariation(self) -> int:
        """
        PanoseStrokeVariation.
        """
        return self._stroke_variation

    @StrokeVariation.setter
    def StrokeVariation(self, value: int) -> None:
        self._stroke_variation = value

    @property
    def ArmStyle(self) -> int:
        """
        PanoseArmStyle.
        """
        return self._arm_style

    @ArmStyle.setter
    def ArmStyle(self, value: int) -> None:
        self._arm_style = value

    @property
    def Letterform(self) -> int:
        """
        PanoseLetterForm.
        """
        return self._letterform

    @Letterform.setter
    def Letterform(self, value: int) -> None:
        self._letterform = value

    @property
    def Midline(self) -> int:
        """
        PanoseMidline.
        """
        return self._midline

    @Midline.setter
    def Midline(self, value: int) -> None:
        self._midline = value

    @property
    def XHeight(self) -> int:
        """
        PanoseXHeight.
        """
        return self._x_height

    @XHeight.setter
    def XHeight(self, value: int) -> None:
        self._x_height = value


__all__ = ['Panose']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XGrid(XInterface_8f010a43):
    """
    provides the possibility of setting and retrieving the position of the current cell in a grid control.
    
    Note that a grid control does not allow free control over the current row: In such a control, every line represents a row of data of the underlying com.sun.star.form.component.DataForm. Thus, the current row of the grid control always equals the current row of the com.sun.star.form.component.DataForm, and can be affected only by changing the latter.The current column of a grid control, whoever, can be freely controlled.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XGrid <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XGrid.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.XGrid'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.XGrid'

    @abstractmethod
    def getCurrentColumnPosition(self) -> int:
        """
        retrieves the current column position.
        """
        ...
    @abstractmethod
    def setCurrentColumnPosition(self, nPos: int) -> None:
        """
        sets the current column position.
        """
        ...

__all__ = ['XGrid']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..awt.point import Point as Point_5fb2085e


class GluePoint(object):
    """
    Struct Class

    A GluePoint could be attached to a shape or to a page.
    
    If a GluePoint is attached to a shape, it is moved when the shape moves. The ends of connectors can be attached to GluePoint.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API GluePoint <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1GluePoint.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.GluePoint'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.drawing.GluePoint'
    """Literal Constant ``com.sun.star.drawing.GluePoint``"""

    def __init__(self, Position: typing.Optional[Point_5fb2085e] = UNO_NONE, EscapeDirection: typing.Optional[int] = 0, PositionAbsolute: typing.Optional[bool] = False, Alignment: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Position (Point, optional): Position value.
            EscapeDirection (int, optional): EscapeDirection value.
            PositionAbsolute (bool, optional): PositionAbsolute value.
            Alignment (int, optional): Alignment value.
        """
        super().__init__()

        if isinstance(Position, GluePoint):
            oth: GluePoint = Position
            self.Position = oth.Position
            self.EscapeDirection = oth.EscapeDirection
            self.PositionAbsolute = oth.PositionAbsolute
            self.Alignment = oth.Alignment
            return

        kargs = {
            "Position": Position,
            "EscapeDirection": EscapeDirection,
            "PositionAbsolute": PositionAbsolute,
            "Alignment": Alignment,
        }
        if kargs["Position"] is UNO_NONE:
            kargs["Position"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._position = kwargs["Position"]
        self._escape_direction = kwargs["EscapeDirection"]
        self._position_absolute = kwargs["PositionAbsolute"]
        self._alignment = kwargs["Alignment"]


    @property
    def Position(self) -> Point_5fb2085e:
        """
        This is the position of this GluePoint.
        """
        return self._position

    @Position.setter
    def Position(self, value: Point_5fb2085e) -> None:
        self._position = value

    @property
    def EscapeDirection(self) -> int:
        """
        This is the direction in which the connector line leaves the GluePoint.
        """
        return self._escape_direction

    @EscapeDirection.setter
    def EscapeDirection(self, value: int) -> None:
        self._escape_direction = value

    @property
    def PositionAbsolute(self) -> bool:
        """
        If this is TRUE, then the position of this GluePoint is absolute on a page and is not relative to a shape.
        """
        return self._position_absolute

    @PositionAbsolute.setter
    def PositionAbsolute(self, value: bool) -> None:
        self._position_absolute = value

    @property
    def Alignment(self) -> int:
        """
        The alignment of a GluePoint defines how the position of the point is affected by resizing the parent Shape.
        """
        return self._alignment

    @Alignment.setter
    def Alignment(self, value: int) -> None:
        self._alignment = value


__all__ = ['GluePoint']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.embed
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..io.io_exception import IOException as IOException_8c450a27
from ..uno.x_interface import XInterface as XInterface_8f010a43

class UseBackupException(IOException_8c450a27):
    """
    Exception Class

    This exception can be thrown in case a storage commit is failed.
    
    If a commit process of a storage fails on last transfer and the original content may be corrupted the storage should throw this exception to notify the user that a backup usage is required to restore the original content.
    
    The storage itself must disconnect from the medium it is based on to allow restoring. Although the storage will still contain all the data internally, and can be used as a temporary storage usually used.

    See Also:
        `API UseBackupException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1embed_1_1UseBackupException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.UseBackupException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.embed.UseBackupException'
    __pyunostruct__: str = 'com.sun.star.embed.UseBackupException'

    typeName: str = 'com.sun.star.embed.UseBackupException'
    """Literal Constant ``com.sun.star.embed.UseBackupException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, TemporaryFileURL: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            TemporaryFileURL (str, optional): TemporaryFileURL value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "TemporaryFileURL": TemporaryFileURL,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._temporary_file_url = kwargs["TemporaryFileURL"]
        inst_keys = ('TemporaryFileURL',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def TemporaryFileURL(self) -> str:
        """
        The URL of the temporary file the storage is based on now.
        """
        return self._temporary_file_url
    
    @TemporaryFileURL.setter
    def TemporaryFileURL(self, value: str) -> None:
        self._temporary_file_url = value


__all__ = ['UseBackupException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.smarttags
from __future__ import annotations
from .x_smart_tag_recognizer import XSmartTagRecognizer as XSmartTagRecognizer_5ccd1071

class SmartTagRecognizer(XSmartTagRecognizer_5ccd1071):
    """
    Service Class

    recognizes smart tags.
    
    Implementations of this service are used to scan the document text for smart tags. Smart tags are pieces of text that can be associated with specific actions which are defined by implementations of the SmartTagAction service.
    
    **since**
    
        OOo 2.3

    See Also:
        `API SmartTagRecognizer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1smarttags_1_1SmartTagRecognizer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.smarttags'
    __ooo_full_ns__: str = 'com.sun.star.smarttags.SmartTagRecognizer'
    __ooo_type_name__: str = 'service'


__all__ = ['SmartTagRecognizer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from .enhanced_custom_shape_parameter_pair import EnhancedCustomShapeParameterPair as EnhancedCustomShapeParameterPair_262914a3
    from .enhanced_custom_shape_segment import EnhancedCustomShapeSegment as EnhancedCustomShapeSegment_b07b1249
    from .enhanced_custom_shape_text_frame import EnhancedCustomShapeTextFrame as EnhancedCustomShapeTextFrame_d6321306

class EnhancedCustomShapePath(ABC):
    """
    Service Class

    This service may be represented by a com.sun.star.beans.PropertyValue [].

    See Also:
        `API EnhancedCustomShapePath <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapePath.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.EnhancedCustomShapePath'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Coordinates(self) -> typing.Tuple[EnhancedCustomShapeParameterPair_262914a3, ...]:
        """
        This property is specifying the points that makes the geometry of the shape.
        """
        ...

    @abstractproperty
    def GluePointLeavingDirections(self) -> typing.Tuple[float, ...]:
        """
        This property specifies GluePoint leaving directions.
        """
        ...

    @abstractproperty
    def GluePoints(self) -> typing.Tuple[EnhancedCustomShapeParameterPair_262914a3, ...]:
        """
        This property specifies custom gluepoints.
        """
        ...

    @abstractproperty
    def Segments(self) -> typing.Tuple[EnhancedCustomShapeSegment_b07b1249, ...]:
        """
        This property specifies the commands and the way the Coordinates have to be interpreted.
        """
        ...

    @abstractproperty
    def SubViewSize(self) -> typing.Tuple[Size_576707ef, ...]:
        """
        This property specifies view size per sub path.
        """
        ...

    @abstractproperty
    def TextFrames(self) -> typing.Tuple[EnhancedCustomShapeTextFrame_d6321306, ...]:
        """
        This property specifies the text frames that can be used with the shape.
        
        In general the first text frame is used, except the shape is containing vertical text, then the object tries to use the second text frame. The default text frame will be as big as the shape.
        """
        ...

    @abstractproperty
    def ConcentricGradientFillAllowed(self) -> bool:
        """
        This property specifies if this shape supports concentric gradient fill.
        
        The default is false.
        """
        ...

    @abstractproperty
    def ExtrusionAllowed(self) -> bool:
        """
        This property specifies if this shape supports the EnhancedCustomShapeExtrusion properties.
        
        The default is true.
        """
        ...

    @abstractproperty
    def GluePointType(self) -> int:
        """
        This property defines the GluePoint type.
        
        The values that can be used are specified in com.sun.star.drawing.EnhancedCustomShapeGluePointType
        """
        ...

    @abstractproperty
    def StretchX(self) -> int:
        """
        This property specifies the horizontal StretchPoint that has to be used.
        
        No stretching is used if this property is omitted.
        """
        ...

    @abstractproperty
    def StretchY(self) -> int:
        """
        This property specifies the vertical StretchPoint that has to be used.
        
        No stretching is used if this property is omitted.
        """
        ...

    @abstractproperty
    def TextPathAllowed(self) -> bool:
        """
        This property specifies if this shape supports concentric gradient fill.
        
        The default is false;
        """
        ...


__all__ = ['EnhancedCustomShapePath']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from .....lo.xml.crypto.sax.const_of_security_id import ConstOfSecurityId as ConstOfSecurityId
from .....lo.xml.crypto.sax.element_mark_priority import ElementMarkPriority as ElementMarkPriority
from .....lo.xml.crypto.sax.element_mark_type import ElementMarkType as ElementMarkType
from .....lo.xml.crypto.sax.element_stack_item import ElementStackItem as ElementStackItem
from .....lo.xml.crypto.sax.x_blocker_monitor import XBlockerMonitor as XBlockerMonitor
from .....lo.xml.crypto.sax.x_decryption_result_broadcaster import XDecryptionResultBroadcaster as XDecryptionResultBroadcaster
from .....lo.xml.crypto.sax.x_decryption_result_listener import XDecryptionResultListener as XDecryptionResultListener
from .....lo.xml.crypto.sax.x_element_stack_keeper import XElementStackKeeper as XElementStackKeeper
from .....lo.xml.crypto.sax.x_encryption_result_broadcaster import XEncryptionResultBroadcaster as XEncryptionResultBroadcaster
from .....lo.xml.crypto.sax.x_encryption_result_listener import XEncryptionResultListener as XEncryptionResultListener
from .....lo.xml.crypto.sax.x_key_collector import XKeyCollector as XKeyCollector
from .....lo.xml.crypto.sax.x_mission_taker import XMissionTaker as XMissionTaker
from .....lo.xml.crypto.sax.x_reference_collector import XReferenceCollector as XReferenceCollector
from .....lo.xml.crypto.sax.x_reference_resolved_broadcaster import XReferenceResolvedBroadcaster as XReferenceResolvedBroadcaster
from .....lo.xml.crypto.sax.x_reference_resolved_listener import XReferenceResolvedListener as XReferenceResolvedListener
from .....lo.xml.crypto.sax.xsax_event_keeper import XSAXEventKeeper as XSAXEventKeeper
from .....lo.xml.crypto.sax.xsax_event_keeper_status_change_broadcaster import XSAXEventKeeperStatusChangeBroadcaster as XSAXEventKeeperStatusChangeBroadcaster
from .....lo.xml.crypto.sax.xsax_event_keeper_status_change_listener import XSAXEventKeeperStatusChangeListener as XSAXEventKeeperStatusChangeListener
from .....lo.xml.crypto.sax.x_security_sax_event_keeper import XSecuritySAXEventKeeper as XSecuritySAXEventKeeper
from .....lo.xml.crypto.sax.x_signature_creation_result_broadcaster import XSignatureCreationResultBroadcaster as XSignatureCreationResultBroadcaster
from .....lo.xml.crypto.sax.x_signature_creation_result_listener import XSignatureCreationResultListener as XSignatureCreationResultListener
from .....lo.xml.crypto.sax.x_signature_verify_result_broadcaster import XSignatureVerifyResultBroadcaster as XSignatureVerifyResultBroadcaster
from .....lo.xml.crypto.sax.x_signature_verify_result_listener import XSignatureVerifyResultListener as XSignatureVerifyResultListener



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ....dyn.awt.tree.expand_veto_exception import ExpandVetoException as ExpandVetoException
with suppress(ImportError):
    from ....dyn.awt.tree.mutable_tree_data_model import MutableTreeDataModel as MutableTreeDataModel
with suppress(ImportError):
    from ....dyn.awt.tree.mutable_tree_node import MutableTreeNode as MutableTreeNode
with suppress(ImportError):
    from ....dyn.awt.tree.tree_control import TreeControl as TreeControl
with suppress(ImportError):
    from ....dyn.awt.tree.tree_control_model import TreeControlModel as TreeControlModel
with suppress(ImportError):
    from ....dyn.awt.tree.tree_data_model_event import TreeDataModelEvent as TreeDataModelEvent
with suppress(ImportError):
    from ....dyn.awt.tree.tree_expansion_event import TreeExpansionEvent as TreeExpansionEvent
with suppress(ImportError):
    from ....dyn.awt.tree.x_mutable_tree_data_model import XMutableTreeDataModel as XMutableTreeDataModel
with suppress(ImportError):
    from ....dyn.awt.tree.x_mutable_tree_node import XMutableTreeNode as XMutableTreeNode
with suppress(ImportError):
    from ....dyn.awt.tree.x_tree_control import XTreeControl as XTreeControl
with suppress(ImportError):
    from ....dyn.awt.tree.x_tree_data_model import XTreeDataModel as XTreeDataModel
with suppress(ImportError):
    from ....dyn.awt.tree.x_tree_data_model_listener import XTreeDataModelListener as XTreeDataModelListener
with suppress(ImportError):
    from ....dyn.awt.tree.x_tree_edit_listener import XTreeEditListener as XTreeEditListener
with suppress(ImportError):
    from ....dyn.awt.tree.x_tree_expansion_listener import XTreeExpansionListener as XTreeExpansionListener
with suppress(ImportError):
    from ....dyn.awt.tree.x_tree_node import XTreeNode as XTreeNode



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.system.simple_command_mail import SimpleCommandMail as SimpleCommandMail
with suppress(ImportError):
    from ...dyn.system.simple_mail_client_flags import SimpleMailClientFlags as SimpleMailClientFlags
with suppress(ImportError):
    from ...dyn.system.simple_mail_client_flags import SimpleMailClientFlagsEnum as SimpleMailClientFlagsEnum
with suppress(ImportError):
    from ...dyn.system.simple_system_mail import SimpleSystemMail as SimpleSystemMail
with suppress(ImportError):
    from ...dyn.system.system_shell_execute import SystemShellExecute as SystemShellExecute
with suppress(ImportError):
    from ...dyn.system.system_shell_execute_exception import SystemShellExecuteException as SystemShellExecuteException
with suppress(ImportError):
    from ...dyn.system.system_shell_execute_flags import SystemShellExecuteFlags as SystemShellExecuteFlags
with suppress(ImportError):
    from ...dyn.system.system_shell_execute_flags import SystemShellExecuteFlagsEnum as SystemShellExecuteFlagsEnum
with suppress(ImportError):
    from ...dyn.system.x_simple_mail_client import XSimpleMailClient as XSimpleMailClient
with suppress(ImportError):
    from ...dyn.system.x_simple_mail_client_supplier import XSimpleMailClientSupplier as XSimpleMailClientSupplier
with suppress(ImportError):
    from ...dyn.system.x_simple_mail_message import XSimpleMailMessage as XSimpleMailMessage
with suppress(ImportError):
    from ...dyn.system.x_simple_mail_message2 import XSimpleMailMessage2 as XSimpleMailMessage2
with suppress(ImportError):
    from ...dyn.system.x_system_shell_execute import XSystemShellExecute as XSystemShellExecute



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from .x_color_scheme import XColorScheme as XColorScheme_c4be0bf8
    from .x_legend import XLegend as XLegend_8cce09f3
    from .data.x_data_source import XDataSource as XDataSource_f6340d57

class XDiagram(XInterface_8f010a43):
    """

    See Also:
        `API XDiagram <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XDiagram.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.XDiagram'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.XDiagram'

    @abstractmethod
    def getDefaultColorScheme(self) -> XColorScheme_c4be0bf8:
        """
        returns an XColorScheme that defines the default colors for data series (or data points) in the diagram.
        """
        ...
    @abstractmethod
    def getFloor(self) -> XPropertySet_bc180bfa:
        """
        returns the property set that determines the visual appearance of the floor if any.
        
        The floor is the bottom of a 3D diagram. For a 2D diagram NULL is returned.
        """
        ...
    @abstractmethod
    def getLegend(self) -> XLegend_8cce09f3:
        """
        returns the legend, which may represent data series and other information about a diagram in a separate box.
        """
        ...
    @abstractmethod
    def getWall(self) -> XPropertySet_bc180bfa:
        """
        returns the property set that determines the visual appearance of the wall.
        
        The wall is the area behind the union of all coordinate systems used in a diagram.
        """
        ...
    @abstractmethod
    def setDefaultColorScheme(self, xColorScheme: XColorScheme_c4be0bf8) -> None:
        """
        sets an XColorScheme that defines the default colors for data series (or data points) in the diagram.
        """
        ...
    @abstractmethod
    def setDiagramData(self, xDataSource: XDataSource_f6340d57, aArguments: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        sets new data to the diagram.
        
        For standard parameters that may be used, see the service StandardDiagramCreationParameters.
        """
        ...
    @abstractmethod
    def setLegend(self, xLegend: XLegend_8cce09f3) -> None:
        """
        sets a new legend.
        """
        ...

__all__ = ['XDiagram']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ...accessibility.x_accessible import XAccessible as XAccessible_1cbc0eb6

class XPane2(ABC):
    """
    An extension of the XPane interface that adds support for a) showing and hiding the windows that internally belong to the pane and b) setting the accessibility object.
    
    This is typically an optional interface.

    See Also:
        `API XPane2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XPane2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XPane2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XPane2'

    @abstractmethod
    def getAccessible(self) -> XAccessible_1cbc0eb6:
        """
        Return the accessibility object that is currently associated with the windows that implement the pane.
        """
        ...
    @abstractmethod
    def isVisible(self) -> bool:
        """
        Return whether all windows that are used to implement the pane are visible.
        """
        ...
    @abstractmethod
    def setAccessible(self, xAccessible: XAccessible_1cbc0eb6) -> None:
        """
        Set the accessibility object for the pane.
        
        When there is more than one window used to implement the pane then the given accessibility object is usually set at the topmost window. However, the details are implementation dependent.
        """
        ...
    @abstractmethod
    def setVisible(self, bIsVisible: bool) -> None:
        """
        Hide or show the pane.
        
        If there is more than one window used to implement the pane then it is left to the implementation if one, some, or all windows are hidden or shown as long as the pane becomes hidden or visible.
        """
        ...

__all__ = ['XPane2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XIndexEntrySupplier(XInterface_8f010a43):
    """
    supplies information on index entries to generate a \"table ofalphabetical index\" for a given locale.

    See Also:
        `API XIndexEntrySupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XIndexEntrySupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XIndexEntrySupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XIndexEntrySupplier'

    @abstractmethod
    def getIndexCharacter(self, aIndexEntry: str, aLocale: Locale_70d308fa, aSortAlgorithm: str) -> str:
        """
        returns the capital index key for sorting a table of indexes, to a given index entry, to a given com.sun.star.lang.Locale and to a given sort algorithm.
        
        For example, in English locale it returns \"K\" for \"keyboard\"
        """
        ...
    @abstractmethod
    def getIndexFollowPageWord(self, bMorePages: bool, aLocale: Locale_70d308fa) -> str:
        """
        returns the page number word of an index entry, where one page or more pages are combined to one page number entry, for a given com.sun.star.lang.Locale.
        
        For example, in English locale it returns \"p.\" for bMorePages == FALSE \"pp.\" for bMorePages == TRUE
        """
        ...

__all__ = ['XIndexEntrySupplier']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet


class IconSetType(object):
    """
    Const Class


    See Also:
        `API IconSetType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.IconSetType'
    __ooo_type_name__: str = 'const'

    ICONSET_3ARROWS = 0
    ICONSET_3ARROWS_GRAY = 1
    ICONSET_3FLAGS = 2
    ICONSET_3TRAFFICLIGHTS1 = 3
    ICONSET_3TRAFFICLIGHTS2 = 4
    ICONSET_3SIGNS = 5
    ICONSET_3SYMBOLS = 6
    ICONSET_3SYMBOLS2 = 7
    ICONSET_3SMILIES = 8
    ICONSET_3COLOR_SIMILIES = 9
    ICONSET_4ARROWS = 10
    ICONSET_4ARROWS_GRAY = 11
    ICONSET_4RED_TO_BLACK = 12
    ICONSET_4RATING = 13
    ICONSET_4TRAFFICLIGHTS = 14
    ICONSET_5ARROWS = 15
    ICONSET_5ARROWS_GRAY = 16
    ICONSET_5RATINGS = 17
    ICONSET_5QUARTERS = 18

__all__ = ['IconSetType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .configuration_change_event import ConfigurationChangeEvent as ConfigurationChangeEvent_55151590
    from .x_configuration_change_listener import XConfigurationChangeListener as XConfigurationChangeListener_adee172c

class XConfigurationControllerBroadcaster(ABC):
    """
    Manage the set of registered event listeners and the event notification for a configuration controller.
    
    The listeners are called in the order in which they are registered.

    See Also:
        `API XConfigurationControllerBroadcaster <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfigurationControllerBroadcaster.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XConfigurationControllerBroadcaster'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XConfigurationControllerBroadcaster'

    @abstractmethod
    def addConfigurationChangeListener(self, xListener: XConfigurationChangeListener_adee172c, sEventType: str, aUserData: object) -> None:
        """
        Add a new listener for configuration changes.
        
        The listener is notified only for the specified type of configuration changes. When the listener is interested in more than one event type this method has to be called multiple times. Alternatively it can register as universal listener that will be called for all event types. However, this option is provided primarily to support debugging and monitoring.
        """
        ...
    @abstractmethod
    def notifyEvent(self, aEvent: ConfigurationChangeEvent_55151590) -> None:
        """
        With this method other objects can send events to all the registered listeners.
        """
        ...
    @abstractmethod
    def removeConfigurationChangeListener(self, xListener: XConfigurationChangeListener_adee172c) -> None:
        """
        Remove a listener for configuration changes.
        """
        ...

__all__ = ['XConfigurationControllerBroadcaster']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ConditionFormatOperator(metaclass=UnoConstMeta, type_name="com.sun.star.sheet.ConditionFormatOperator", name_space="com.sun.star.sheet"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sheet.ConditionFormatOperator``"""
        pass

    class ConditionFormatOperatorEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sheet.ConditionFormatOperator", name_space="com.sun.star.sheet"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sheet.ConditionFormatOperator`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.sheet import ConditionFormatOperator as ConditionFormatOperator
    else:
        # keep document generators happy
        from ...lo.sheet.condition_format_operator import ConditionFormatOperator as ConditionFormatOperator

    class ConditionFormatOperatorEnum(IntEnum):
        """
        Enum of Const Class ConditionFormatOperator

        """
        EQUAL = ConditionFormatOperator.EQUAL
        LESS = ConditionFormatOperator.LESS
        GREATER = ConditionFormatOperator.GREATER
        LESS_EQUAL = ConditionFormatOperator.LESS_EQUAL
        GREATER_EQUAL = ConditionFormatOperator.GREATER_EQUAL
        NOT_EQUAL = ConditionFormatOperator.NOT_EQUAL
        BETWEEN = ConditionFormatOperator.BETWEEN
        NOT_BETWEEN = ConditionFormatOperator.NOT_BETWEEN
        DUPLICATE = ConditionFormatOperator.DUPLICATE
        UNIQUE = ConditionFormatOperator.UNIQUE
        TOP_N_ELEMENTS = ConditionFormatOperator.TOP_N_ELEMENTS
        BOTTOM_N_ELEMENTS = ConditionFormatOperator.BOTTOM_N_ELEMENTS
        TOP_N_PERCENT = ConditionFormatOperator.TOP_N_PERCENT
        BOTTOM_N_PERCENT = ConditionFormatOperator.BOTTOM_N_PERCENT
        ABOVE_AVERAGE = ConditionFormatOperator.ABOVE_AVERAGE
        BELOW_AVERAGE = ConditionFormatOperator.BELOW_AVERAGE
        ABOVE_EQUAL_AVERAGE = ConditionFormatOperator.ABOVE_EQUAL_AVERAGE
        BELOW_EQUAL_AVERAGE = ConditionFormatOperator.BELOW_EQUAL_AVERAGE
        ERROR = ConditionFormatOperator.ERROR
        NO_ERROR = ConditionFormatOperator.NO_ERROR
        BEGINS_WITH = ConditionFormatOperator.BEGINS_WITH
        ENDS_WITH = ConditionFormatOperator.ENDS_WITH
        CONTAINS = ConditionFormatOperator.CONTAINS
        NOT_CONTAINS = ConditionFormatOperator.NOT_CONTAINS
        EXPRESSION = ConditionFormatOperator.EXPRESSION

__all__ = ['ConditionFormatOperator', 'ConditionFormatOperatorEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbcx
from __future__ import annotations
from abc import abstractproperty
from .descriptor import Descriptor as Descriptor_a5200b3b
from .x_columns_supplier import XColumnsSupplier as XColumnsSupplier_f0600da9

class KeyDescriptor(Descriptor_a5200b3b, XColumnsSupplier_f0600da9):
    """
    Service Class

    is used to define a new key for a table.

    See Also:
        `API KeyDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbcx_1_1KeyDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbcx'
    __ooo_full_ns__: str = 'com.sun.star.sdbcx.KeyDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DeleteRule(self) -> int:
        """
        is the rule which is applied for deletions; only used for foreign keys.
        """
        ...

    @abstractproperty
    def ReferencedTable(self) -> str:
        """
        is the name of the referenced table, only used for foreign keys.
        """
        ...

    @abstractproperty
    def Type(self) -> int:
        """
        indicates the type of the key.
        """
        ...

    @abstractproperty
    def UpdateRule(self) -> int:
        """
        is the rule which is applied for updates; only used for foreign keys.
        """
        ...


__all__ = ['KeyDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..awt.x_bitmap import XBitmap as XBitmap_70cd0909
    from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe

class ActionTrigger(ABC):
    """
    Service Class

    describes a trigger for an (user inter-)action.
    
    Common examples for such triggers are menu entries or toolbar icons.

    See Also:
        `API ActionTrigger <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1ActionTrigger.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.ActionTrigger'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CommandURL(self) -> str:
        """
        contains the command URL for the menu entry.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        contains the a URL that points to a help text.
        """
        ...

    @abstractproperty
    def Image(self) -> XBitmap_70cd0909:
        """
        contains the menu item image.
        """
        ...

    @abstractproperty
    def SubContainer(self) -> XIndexContainer_1c040ebe:
        """
        contains a sub menu.
        """
        ...

    @abstractproperty
    def Text(self) -> str:
        """
        contains the text of the menu entry.
        """
        ...


__all__ = ['ActionTrigger']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt


class MouseWheelBehavior(object):
    """
    Const Class

    describes the scroll behavior of the mouse wheel for a control
    
    **since**
    
        OOo 3.2

    See Also:
        `API MouseWheelBehavior <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1MouseWheelBehavior.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.MouseWheelBehavior'
    __ooo_type_name__: str = 'const'

    SCROLL_DISABLED = 0
    """
    defines that the mouse wheel cannot be used to scroll through the control's content
    """
    SCROLL_FOCUS_ONLY = 1
    """
    defines that the mouse can only be used to scroll through the control's content if it currently has the focus.
    """
    SCROLL_ALWAYS = 2
    """
    defines that the mouse can be used to scroll through the control's content, no matter whether or not it has the focus, as long as the mouse pointer is over the control.
    """

__all__ = ['MouseWheelBehavior']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractproperty
from .uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
if typing.TYPE_CHECKING:
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc

class UnoControlRoadmapModel(UnoControlModel_c8ce0c58, XIndexContainer_1c040ebe):
    """
    Service Class

    specifies the standard model of a UnoControlContainer.
    
    **since**
    
        OOo 2.1

    See Also:
        `API UnoControlRoadmapModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRoadmapModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.UnoControlRoadmapModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BackgroundColor(self) -> int:
        """
        specifies the background color (RGB) of the control.
        
        The Default value is white
        """
        ...

    @abstractproperty
    def Border(self) -> int:
        """
        specifies the border style of the control.
        """
        ...

    @abstractproperty
    def Complete(self) -> bool:
        """
        determines whether the control container is complete or not.
        
        If it is false than a non - interactive RoadmapItem is appended
        """
        ...

    @abstractproperty
    def CurrentItemID(self) -> int:
        """
        refers to the ID of the currently selected item.
        
        Initially this property is set to \"-1\" which is equal to \"undefined\" If the Roadmap Item that the CurrentItemID refers to is removed the property \"CurrentItemID\" is set to -1
        """
        ...

    @abstractproperty
    def Graphic(self) -> XGraphic_a4da0afc:
        """
        specifies a graphic to be displayed on the control
        
        If this property is present, it interacts with the ImageURL in the following way:
        
        **since**
        
            OOo 2.1
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        specifies the help text of the control.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        specifies the help URL of the control.
        """
        ...

    @abstractproperty
    def ImageURL(self) -> str:
        """
        specifies a URL to an image to use for the control.
        
        The image is placed in the lower right corner of the control
        """
        ...

    @abstractproperty
    def Interactive(self) -> bool:
        """
        determines whether the control is interactive or not.
        
        A roadmap control which is interactive allows selecting its items out-of-order, by simply clicking them.
        """
        ...

    @abstractproperty
    def Printable(self) -> bool:
        """
        specifies whether the control will be printed with the document.
        """
        ...

    @abstractproperty
    def Text(self) -> str:
        """
        specifies the text displayed in the control.
        """
        ...


__all__ = ['UnoControlRoadmapModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_result_set import XResultSet as XResultSet_98e30aa7

class XGeneratedResultSet(XInterface_8f010a43):
    """
    provides a result set which gives access to automatically generated values after a new row was inserted.
    
    The relative order of columns in the result set returned by getGeneratedValues() must be the same as the relative order of the same columns as returned when executing a \"SELECT * FROM table\". This ensures that clients of this interface can reliably fetch the column values.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XGeneratedResultSet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XGeneratedResultSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XGeneratedResultSet'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XGeneratedResultSet'

    @abstractmethod
    def getGeneratedValues(self) -> XResultSet_98e30aa7:
        """
        gives access to automatically generated values after a new row was inserted.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XGeneratedResultSet']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class WizardTravelType(metaclass=UnoConstMeta, type_name="com.sun.star.ui.dialogs.WizardTravelType", name_space="com.sun.star.ui.dialogs"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.ui.dialogs.WizardTravelType``"""
        pass

    class WizardTravelTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.ui.dialogs.WizardTravelType", name_space="com.sun.star.ui.dialogs"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.ui.dialogs.WizardTravelType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.ui.dialogs import WizardTravelType as WizardTravelType
    else:
        # keep document generators happy
        from ....lo.ui.dialogs.wizard_travel_type import WizardTravelType as WizardTravelType

    class WizardTravelTypeEnum(IntEnum):
        """
        Enum of Const Class WizardTravelType

        denotes ways to leave a Wizard's page
        
        **since**
        
            OOo 3.3
        """
        FORWARD = WizardTravelType.FORWARD
        """
        indicates the wizard page is left due to forward traveling through the wizard
        """
        BACKWARD = WizardTravelType.BACKWARD
        """
        indicates the wizard page is left due to backward traveling through the wizard
        """
        FINISH = WizardTravelType.FINISH
        """
        indicates the wizard page is left since the wizard is about to be finished
        """

__all__ = ['WizardTravelType', 'WizardTravelTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class GraphicCrop(object):
    """
    Struct Class

    describes the cropping of graphic objects.
    
    Cropping means to show only parts of the object.
    
    Negative values cut the visible area; positive values extend the visible area by filling it with background color. The absolute sum of top and bottom crop must be smaller than the objects original height. The absolute sum of the left and right crop must be smaller than the object's original width.
    
    If this property is applied to a graphic object, then this object will correct these values if necessary.

    See Also:
        `API GraphicCrop <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1text_1_1GraphicCrop.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.GraphicCrop'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.text.GraphicCrop'
    """Literal Constant ``com.sun.star.text.GraphicCrop``"""

    def __init__(self, Top: typing.Optional[int] = 0, Bottom: typing.Optional[int] = 0, Left: typing.Optional[int] = 0, Right: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Top (int, optional): Top value.
            Bottom (int, optional): Bottom value.
            Left (int, optional): Left value.
            Right (int, optional): Right value.
        """
        super().__init__()

        if isinstance(Top, GraphicCrop):
            oth: GraphicCrop = Top
            self.Top = oth.Top
            self.Bottom = oth.Bottom
            self.Left = oth.Left
            self.Right = oth.Right
            return

        kargs = {
            "Top": Top,
            "Bottom": Bottom,
            "Left": Left,
            "Right": Right,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._top = kwargs["Top"]
        self._bottom = kwargs["Bottom"]
        self._left = kwargs["Left"]
        self._right = kwargs["Right"]


    @property
    def Top(self) -> int:
        """
        contains the top value to cut (if negative) or to extend (if positive)
        """
        return self._top

    @Top.setter
    def Top(self, value: int) -> None:
        self._top = value

    @property
    def Bottom(self) -> int:
        """
        contains the bottom value to cut (if negative) or to extend (if positive)
        """
        return self._bottom

    @Bottom.setter
    def Bottom(self, value: int) -> None:
        self._bottom = value

    @property
    def Left(self) -> int:
        """
        contains the left value to cut (if negative) or to extend (if positive)
        """
        return self._left

    @Left.setter
    def Left(self, value: int) -> None:
        self._left = value

    @property
    def Right(self) -> int:
        """
        contains the right value to cut (if negative) or to extend (if positive)
        """
        return self._right

    @Right.setter
    def Right(self, value: int) -> None:
        self._right = value


__all__ = ['GraphicCrop']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .property import Property as Property_8f4e0a76
    from ..reflection.x_idl_method import XIdlMethod as XIdlMethod_e3740d05

class XIntrospectionAccess(XInterface_8f010a43):
    """
    represents the result of an introspection operation done by the inspect method of XIntrospection.
    
    This interface gives information about an object's properties and methods as detected in the introspection process. It's not possible to access properties or call methods directly using this interface but it provides access to other interfaces to do so. See com.sun.star.beans.XIntrospectionAccess.queryAdapter()
    
    The XExactName interface has to be supported in order to implement inaccurate name access for all objects which implement the com.sun.star.container.XNameAccess interface or XPropertySet.
    
    The XMaterialHolder interface has to be supported to give access to the inspected object.

    See Also:
        `API XIntrospectionAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XIntrospectionAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.XIntrospectionAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.beans.XIntrospectionAccess'

    @abstractmethod
    def getMethod(self, aName: str, nMethodConcepts: int) -> XIdlMethod_e3740d05:
        """
        returns information about a method if a method with the demanded name exists and if it accords to one of the demanded MethodConcepts.
        
        The information is provided as com.sun.star.reflection.XIdlMethod.

        Raises:
            com.sun.star.lang.NoSuchMethodException: ``NoSuchMethodException``
        """
        ...
    @abstractmethod
    def getMethods(self, nMethodConcepts: int) -> typing.Tuple[XIdlMethod_e3740d05, ...]:
        """
        returns a sequence of methods of the introspected object.
        """
        ...
    @abstractmethod
    def getProperties(self, nPropertyConcepts: int) -> typing.Tuple[Property_8f4e0a76, ...]:
        """
        returns a sequence of properties of the introspected object
        """
        ...
    @abstractmethod
    def getProperty(self, aName: str, nPropertyConcepts: int) -> Property_8f4e0a76:
        """
        returns information about a property if a property with the demanded name exists and if it accords to one of the demanded PropertyConcepts.
        
        The information is provided as Property struct.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def getSuppliedMethodConcepts(self) -> int:
        """
        returns information about which method concepts described in the MethodConcept constants group are supported by this XIntrospectionAccess implementation.
        
        The minimum supported concepts should be:
        """
        ...
    @abstractmethod
    def getSuppliedPropertyConcepts(self) -> int:
        """
        returns information about which property concepts described in the PropertyConcept constants group are supported by this XIntrospectionAccess implementation.
        
        The minimum supported concepts should be:
        """
        ...
    @abstractmethod
    def getSupportedListeners(self) -> typing.Tuple[object, ...]:
        """
        returns the listener types supported by the introspected object.
        
        If the introspected object has the methods addFooListener( XFooListener xFoo ) and removeFooListener( XFooListener xFoo ) the type of XFooListener will be one of the elements in the returned sequence.
        """
        ...
    @abstractmethod
    def hasMethod(self, aName: str, nMethodConcepts: int) -> bool:
        """
        allows to ask if a method with the demanded name exists and if it accords to one of the demanded MethodConcept.
        """
        ...
    @abstractmethod
    def hasProperty(self, aName: str, nPropertyConcepts: int) -> bool:
        """
        allows to ask if a property with the demanded name exists and if it accords to one of the demanded PropertyConcept.
        """
        ...
    @abstractmethod
    def queryAdapter(self, aInterfaceType: object) -> XInterface_8f010a43:
        """
        creates an adapter that implements an interface with the specified type.
        
        To access properties, query for the XPropertySet interface. If the XPropertySet can be queried, the XFastPropertySet interface must be supported too.
        
        If the introspected object implements a name container, the introspection should return the com.sun.star.container.XNameAccess and com.sun.star.container.XNameContainer interfaces.
        
        If the introspected object implements an index container, the introspection should return the com.sun.star.container.XIndexAccess and com.sun.star.container.XIndexContainer interfaces.
        
        If the introspected object implements an enumeration container, the introspection should return the com.sun.star.container.XEnumerationAccess interface.
        
        If the introspected object implements the com.sun.star.reflection.XIdlArray interface, the introspection should return this.
        
        To implement inaccurate name access, at all objects, which implement the com.sun.star.container.XNameAccess or XPropertySet interface, the XExactName interface has to be supported.

        Raises:
            com.sun.star.beans.IllegalTypeException: ``IllegalTypeException``
        """
        ...

__all__ = ['XIntrospectionAccess']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rdf


class FileFormat(object):
    """
    Const Class

    Constants to specify RDF file formats.
    
    These constants are mainly for use with XRepository.importGraph() and XRepository.exportGraph().
    
    Note that these are integers because UNO IDL does not permit string constants.
    
    **since**
    
        OOo 3.0

    See Also:
        `API FileFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rdf_1_1FileFormat.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rdf'
    __ooo_full_ns__: str = 'com.sun.star.rdf.FileFormat'
    __ooo_type_name__: str = 'const'

    RDF_XML = 0
    """
    RDF/XML
    """
    N3 = 1
    """
    N3 (Notation-3)
    """
    NTRIPLES = 2
    """
    N-Triples
    """
    TRIG = 3
    """
    TriG
    """
    TRIX = 4
    """
    TriX
    """
    TURTLE = 5
    """
    Turtle
    """

__all__ = ['FileFormat']
